]> git.xonotic.org Git - xonotic/darkplaces.git/commitdiff
changed teu game dir to "baseteu" at request of teu team
authorhavoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Fri, 12 Sep 2003 23:57:58 +0000 (23:57 +0000)
committerhavoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Fri, 12 Sep 2003 23:57:58 +0000 (23:57 +0000)
git-svn-id: svn://svn.icculus.org/twilight/trunk/darkplaces@3451 d7cf8633-e32d-0410-b094-e92efae38249

common.c

index 9ae390e0fbcdedb53c00157ba5f76c1e276313c1..5318c14ac79771e476a0c3e71be41a288bc8e409 100644 (file)
--- a/common.c
+++ b/common.c
@@ -219,7 +219,7 @@ void MSG_WriteString (sizebuf_t *sb, const char *s)
                SZ_Write (sb, s, strlen(s)+1);
 }
 
// used by server (always latest dpprotocol)
 void MSG_WriteDPCoord (sizebuf_t *sb, float f)
 {
        if (f >= 0)
@@ -353,7 +353,7 @@ int MSG_ReadBytes (int numbytes, unsigned char *out)
        return l;
 }
 
// used by server (always latest dpprotocol)
 float MSG_ReadDPCoord (void)
 {
        return (signed short) MSG_ReadLittleShort();
@@ -362,9 +362,9 @@ float MSG_ReadDPCoord (void)
 // used by client
 float MSG_ReadCoord (void)
 {
-       if (dpprotocol == DPPROTOCOL_VERSION2 || dpprotocol == DPPROTOCOL_VERSION3 || dpprotocol == DPPROTOCOL_VERSION4)
+       if (cl.protocol == PROTOCOL_DARKPLACES2 || cl.protocol == PROTOCOL_DARKPLACES3 || cl.protocol == PROTOCOL_DARKPLACES4)
                return (signed short) MSG_ReadLittleShort();
-       else if (dpprotocol == DPPROTOCOL_VERSION1)
+       else if (cl.protocol == PROTOCOL_DARKPLACES1)
                return MSG_ReadLittleFloat();
        else
                return MSG_ReadLittleShort() * (1.0f/8.0f);
@@ -748,7 +748,7 @@ void COM_InitGameType (void)
                break;
        case GAME_TEU:
                gamename = "TheEvilUnleashed";
-               gamedirname = "teu";
+               gamedirname = "baseteu";
                break;
        case GAME_BATTLEMECH:
                gamename = "Battlemech";
@@ -219,7 +219,7 @@ void MSG_WriteString (sizebuf_t *sb, const char *s)
 }
 
-// used by server (always latest dpprotocol)
+// used by server (always latest PROTOCOL_DARKPLACES)
 void MSG_WriteDPCoord (sizebuf_t *sb, float f)
 {
@@ -353,7 +353,7 @@ int MSG_ReadBytes (int numbytes, unsigned char *out)
 }
 
-// used by server (always latest dpprotocol)
+// used by server (always latest PROTOCOL_DARKPLACES)
 float MSG_ReadDPCoord (void)
 {